.. _api_elem_tag:

Element Tags (:mod:`pydicom.tag`)
=================================

.. currentmodule:: pydicom.tag

Representation of the data element tag and utilities.

.. autosummary::
   :toctree: generated/

   BaseTag
   Tag
   tag_in_exception
   TupleTag
